==> libkiwix-13.1.0.tar.xz: libkiwix-13.1.0/static/skin/languages.js <==
const uiLanguages = [
  {
    "iso_code": "ar",
    "self_name": "الإنجليزية",
    "translation_count": 25
  },
  {
    "iso_code": "bn",
    "self_name": "বাংলা",
    "translation_count": 14
  },
  {
    "iso_code": "br",
    "self_name": "brezhoneg",
    "translation_count": 35
  },
  {
    "iso_code": "cs",
    "self_name": "Čeština",
    "translation_count": 25
  },
  {
    "iso_code": "dag",
    "self_name": "Silimiinsili",
    "translation_count": 24
  },
  {
    "iso_code": "de",
    "self_name": "Deutsch",
    "translation_count": 57
  },
  {
    "iso_code": "en",
    "self_name": "English",
    "translation_count": 58
  },
  {
    "iso_code": "es",
    "self_name": "español",
    "translation_count": 48
  },
  {
    "iso_code": "fi",
    "self_name": "suomi",
    "translation_count": 22
  },
  {
    "iso_code": "fr",
    "self_name": "Français",
    "translation_count": 57
  },
  {
    "iso_code": "ha",
    "self_name": "Turanci",
    "translation_count": 57
  },
  {
    "iso_code": "he",
    "self_name": "עברית",
    "translation_count": 57
  },
  {
    "iso_code": "hi",
    "self_name": "हिन्दी",
    "translation_count": 49
  },
  {
    "iso_code": "hy",
    "self_name": "Հայերեն",
    "translation_count": 15
  },
  {
    "iso_code": "ia",
    "self_name": "interlingua",
    "translation_count": 49
  },
  {
    "iso_code": "ig",
    "self_name": "Bekee",
    "translation_count": 57
  },
  {
    "iso_code": "it",
    "self_name": "italiano",
    "translation_count": 34
  },
  {
    "iso_code": "ja",
    "self_name": "日本語",
    "translation_count": 26
  },
  {
    "iso_code": "ko",
    "self_name": "한국어",
    "translation_count": 13
  },
  {
    "iso_code": "ku-latn",
    "self_name": "kurdî",
    "translation_count": 26
  },
  {
    "iso_code": "lb",
    "self_name": "Lëtzebuergesch",
    "translation_count": 22
  },
  {
    "iso_code": "mk",
    "self_name": "македонски",
    "translation_count": 57
  },
  {
    "iso_code": "ms",
    "self_name": "Bahasa Melayu",
    "translation_count": 14
  },
  {
    "iso_code": "nl",
    "self_name": "Nederlands",
    "translation_count": 49
  },
  {
    "iso_code": "nqo",
    "self_name": "ߒߞߏ",
    "translation_count": 43
  },
  {
    "iso_code": "or",
    "self_name": "ଓଡ଼ିଆ",
    "translation_count": 49
  },
  {
    "iso_code": "pl",
    "self_name": "Polski",
    "translation_count": 31
  },
  {
    "iso_code": "ru",
    "self_name": "русский",
    "translation_count": 57
  },
  {
    "iso_code": "sc",
    "self_name": "Sardu",
    "translation_count": 49
  },
  {
    "iso_code": "sk",
    "self_name": "slovenčina",
    "translation_count": 25
  },
  {
    "iso_code": "skr-arab",
    "self_name": "سرائیکی",
    "translation_count": 20
  },
  {
    "iso_code": "sl",
    "self_name": "slovenščina",
    "translation_count": 57
  },
  {
    "iso_code": "sq",
    "self_name": "Shqip",
    "translation_count": 49
  },
  {
    "iso_code": "sv",
    "self_name": "Svenska",
    "translation_count": 57
  },
  {
    "iso_code": "te",
    "self_name": "ఇంగ్లీషు",
    "translation_count": 49
  },
  {
    "iso_code": "tr",
    "self_name": "Türkçe",
    "translation_count": 57
  },
  {
    "iso_code": "zh-hans",
    "self_name": "英语",
    "translation_count": 54
  },
  {
    "iso_code": "zh-hant",
    "self_name": "繁體中文",
    "translation_count": 57
  }
]

==> libkiwix_14.0.0.orig.tar.xz: libkiwix-14.0.0/static/skin/languages.js <==
const uiLanguages = [
  {
    "iso_code": "ar",
    "self_name": "الإنجليزية",
    "translation_count": 25
  },
  {
    "iso_code": "bn",
    "self_name": "বাংলা",
    "translation_count": 14
  },
  {
    "iso_code": "br",
    "self_name": "brezhoneg",
    "translation_count": 35
  },
  {
    "iso_code": "cs",
    "self_name": "Čeština",
    "translation_count": 25
  },
  {
    "iso_code": "dag",
    "self_name": "Silimiinsili",
    "translation_count": 48
  },
  {
    "iso_code": "de",
    "self_name": "Deutsch",
    "translation_count": 57
  },
  {
    "iso_code": "el",
    "self_name": "Αγγλικά",
    "translation_count": 23
  },
  {
    "iso_code": "en",
    "self_name": "English",
    "translation_count": 58
  },
  {
    "iso_code": "es",
    "self_name": "español",
    "translation_count": 49
  },
  {
    "iso_code": "fi",
    "self_name": "suomi",
    "translation_count": 29
  },
  {
    "iso_code": "fr",
    "self_name": "Français",
    "translation_count": 57
  },
  {
    "iso_code": "ha",
    "self_name": "Turanci",
    "translation_count": 57
  },
  {
    "iso_code": "he",
    "self_name": "עברית",
    "translation_count": 57
  },
  {
    "iso_code": "hi",
    "self_name": "हिन्दी",
    "translation_count": 49
  },
  {
    "iso_code": "hy",
    "self_name": "Հայերեն",
    "translation_count": 15
  },
  {
    "iso_code": "ia",
    "self_name": "interlingua",
    "translation_count": 57
  },
  {
    "iso_code": "ig",
    "self_name": "Bekee",
    "translation_count": 57
  },
  {
    "iso_code": "it",
    "self_name": "italiano",
    "translation_count": 38
  },
  {
    "iso_code": "ja",
    "self_name": "日本語",
    "translation_count": 26
  },
  {
    "iso_code": "ko",
    "self_name": "한국어",
    "translation_count": 15
  },
  {
    "iso_code": "ku-latn",
    "self_name": "kurdî",
    "translation_count": 26
  },
  {
    "iso_code": "lb",
    "self_name": "Lëtzebuergesch",
    "translation_count": 22
  },
  {
    "iso_code": "mk",
    "self_name": "македонски",
    "translation_count": 57
  },
  {
    "iso_code": "ms",
    "self_name": "Bahasa Melayu",
    "translation_count": 14
  },
  {
    "iso_code": "nl",
    "self_name": "Nederlands",
    "translation_count": 49
  },
  {
    "iso_code": "nqo",
    "self_name": "ߒߞߏ",
    "translation_count": 43
  },
  {
    "iso_code": "or",
    "self_name": "ଓଡ଼ିଆ",
    "translation_count": 49
  },
  {
    "iso_code": "pl",
    "self_name": "Polski",
    "translation_count": 31
  },
  {
    "iso_code": "pt-br",
    "self_name": "Português",
    "translation_count": 35
  },
  {
    "iso_code": "ru",
    "self_name": "русский",
    "translation_count": 57
  },
  {
    "iso_code": "sc",
    "self_name": "Sardu",
    "translation_count": 49
  },
  {
    "iso_code": "sk",
    "self_name": "slovenčina",
    "translation_count": 25
  },
  {
    "iso_code": "skr-arab",
    "self_name": "سرائیکی",
    "translation_count": 20
  },
  {
    "iso_code": "sl",
    "self_name": "slovenščina",
    "translation_count": 57
  },
  {
    "iso_code": "sq",
    "self_name": "Shqip",
    "translation_count": 49
  },
  {
    "iso_code": "sv",
    "self_name": "Svenska",
    "translation_count": 57
  },
  {
    "iso_code": "sw",
    "self_name": "Kiswahili",
    "translation_count": 57
  },
  {
    "iso_code": "te",
    "self_name": "ఇంగ్లీషు",
    "translation_count": 49
  },
  {
    "iso_code": "tr",
    "self_name": "Türkçe",
    "translation_count": 57
  },
  {
    "iso_code": "zh-hans",
    "self_name": "简体中文",
    "translation_count": 57
  },
  {
    "iso_code": "zh-hant",
    "self_name": "繁體中文",
    "translation_count": 57
  }
]
